==> elixir-react-stateful-1.2.0.tgz: package/src/config/notifications.js <==
import React from "react";
import { notification, message as AntMessages, Row, Col, Button } from "antd";
import { CloseOutlined, CheckOutlined } from "@ant-design/icons";
import store from "../../redux";
import { confirmAction, setCurrentObjectPath } from "../../redux/actions";
import { getNotificationMethod, getWarningMethod } from "../../initializer";


export const showNotification = getNotificationMethod() ;
export const showWarning = getWarningMethod() ;
/*  export const showNotification = ({
  message,
  description,
  duration,
  type = "info",
  placement = store.getState().general.isRTL ? "topLeft" : "topRight",
  bottom,
  top,
  btn,
  className,
  closeIcon,
  getContainer,
  icon,
  key,
  onClick,
  onClose,
  prefixCls,
  style,
}) => {
  notification[type]({
    placement,
    message,
    description,
    duration,
    type,
    bottom,
    top,
    btn,
    className,
    closeIcon,
    getContainer,
    icon,
    key,
    onClick,
    onClose,
    prefixCls,
    style,
  });
};

export const showWarning = ({ objectPk, title, message }, tdlId, usecaseId, handler=() => {} ) => {
  if(!handler){
    handler = ()=>{
      if (objectPk) {
        store.dispatch(setCurrentObjectPath(usecaseId, objectPk));
      }
      store.dispatch(confirmAction(usecaseId, tdlId));
    }
  }
  const key = `${objectPk}${tdlId}`;
  AntMessages.warn({
    duration: 0,
    key,
    content: (
      <Row gutter={[8, 8]}>
        <Col span={24}>{title}</Col>
        <Col span={24}>{message}</Col>
        <Col span={12}>
          <Button
            onClick={(e) => {
              handler(e);
              AntMessages.destroy(key);
            }}
            icon={<CheckOutlined />}
          >
            {"confirm"}
          </Button>
        </Col>
        <Col span={12}>
          <Button
            onClick={() => {
              AntMessages.destroy(key);
            }}
            icon={<CloseOutlined />}
          >
            {"cancel"}
          </Button>
        </Col>
      </Row>
    ),
  });
};
  */

==> elixir-react-stateful-2.0.1.tgz: package/src/config/notifications.js <==
import React from "react";
import { notification, message as AntMessages, Row, Col, Button } from "antd";
import { CloseOutlined, CheckOutlined } from "@ant-design/icons";
import store from "../../redux";
  import { confirmAction, setCurrentObjectPath } from "../../redux/actions";

export const showNotification = ({
  message,
  description,
  duration,
  type = "info",
  placement = store.getState().general.isRTL ? "topLeft" : "topRight",
  bottom,
  top,
  btn,
  className,
  closeIcon,
  getContainer,
  icon,
  key,
  onClick,
  onClose,
  prefixCls,
  style,
}) => {
  notification[type]({
    placement,
    message,
    description,
    duration,
    type,
    bottom,
    top,
    btn,
    className,
    closeIcon,
    getContainer,
    icon,
    key,
    onClick,
    onClose,
    prefixCls,
    style,
  });
};

export const showWarning = ({ objectPk, title, message }, tdlId, usecaseId, handler=() => {} ) => {
  if(!handler){
    handler = ()=>{
      if (objectPk) {
        store.dispatch(setCurrentObjectPath(usecaseId, objectPk));
      }
      store.dispatch(confirmAction(usecaseId, tdlId));
    }
  }
  const key = `${objectPk}${tdlId}`;
  AntMessages.warn({
    duration: 0,
    key,
    content: (
      <Row gutter={[8, 8]}>
        <Col span={24}>{title}</Col>
        <Col span={24}>{message}</Col>
        <Col span={12}>
          <Button
            onClick={(e) => {
              handler(e);
              AntMessages.destroy(key);
            }}
            icon={<CheckOutlined />}
          >
            {"confirm"}
          </Button>
        </Col>
        <Col span={12}>
          <Button
            onClick={() => {
              AntMessages.destroy(key);
            }}
            icon={<CloseOutlined />}
          >
            {"cancel"}
          </Button>
        </Col>
      </Row>
    ),
  });
};
